==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/admin/messages/hu/settings.php <==
<?php
return array (
  '1 month' => '1 hónap',
  '1 week' => '1 hét',
  '1 year' => '1 év',
  '2 weeks' => '2 év',
  '3 months' => '3 hónap',
  '6 months' => '6 hónap',
  '<strong>Confirm</strong> icon deletion' => '',
  '<strong>Confirm</strong> image deletion' => 'Kép törlésének <strong>megerősítése</strong>',
  'APC(u)' => 'APC(u)',
  'Add OEmbed provider' => 'OEmbed szolgáltató hozzáadása',
  'Add new provider' => 'Új szolgáltató hozzáadása',
  'Advanced Settings' => 'Speciális beállítások',
  'Allow Self-Signed Certificates?' => 'Önaláírt tanúsítványok elfogasása?',
  'Allowed file extensions' => 'Engedélyezett fájlkiterjesztések',
  'Alphabetical' => 'ABC sorrend',
  'Appearance Settings' => 'Megjelenítési beállítások',
  'Back to overview' => 'Vissza az áttekkintéshez',
  'Base URL' => 'Alap URL',
  'Cache Backend' => 'Gyorsítótár backend',
  'Comma separated list. Leave empty to allow all.' => 'Vesszővel elválasztott lista. Hagyd üresen, ha az összeset engedélyezni akarod.',
  'Convert command not found!' => 'A konvertáló parancs nem található!',
  'Current Image Library: {currentImageLibrary}' => 'Aktuális képkönyvtár: {currentImageLibrary}',
  'Currently no provider active!' => 'Jelenleg egyetlen szolgáltató sem aktív!',
  'Currently there are {count} records in the database dating from {dating}.' => 'Jelenleg {count} rekord szerepel az adatbázisban, ami ekkor lett létrehozva {dating}.',
  'Dashboard' => 'Áttekintés',
  'Date input format' => 'Dátum beviteli formátuma',
  'Default Expire Time (in seconds)' => 'Alapértelmezett lejárati idő (másodpercekben)',
  'Default language' => 'Alapértelmezett nyelv',
  'Default pagination size (Entries per page)' => 'Alapértelmezett lapozásméret (oldalankénti bejegyzések)',
  'Default stream content order' => 'A stream tartalmának alapértelmezett sorrendje',
  'Delete' => 'Törlés',
  'Display Name (Format)' => 'Megjelenítési név (formátum)',
  'Dropdown space order' => 'Legördülő közösségek sorrendje',
  'E-Mail' => 'Email',
  'E-Mail sender address' => 'Email küldőjének címe',
  'E-Mail sender name' => 'E-mail küldőjének neve',
  'E.g. http://example.com/humhub' => 'Pl. http://example.com/humhub',
  'Edit OEmbed provider' => 'OEmbed szolgáltató szerkesztése',
  'Enable user friendship system' => 'Felhasználók barátkozásának engedélyezése',
  'Enabled' => 'Bekacsolva',
  'Enabled OEmbed providers' => 'Engedélyezett OEmbed szolgáltatók',
  'Encryption' => 'Enkriptálás',
  'Endpoint Url' => 'Végpont URL',
  'File' => 'Fájl',
  'Firstname Lastname (e.g. John Doe)' => 'Keresztnév/utónév (például John Doe)',
  'Friendship' => 'Ismerősök',
  'General' => 'Általános',
  'General Settings' => 'Általános beállítások',
  'Got invalid image magick response! - Correct command?' => 'Érvénytelen image magick válasz! - Helyes parancs?',
  'HTML tracking code' => 'HTML-követőkód',
  'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Itt konfigurálhatod közösségi hálózatod regisztrálói viselkedéssel kapcsolatos beállításait és további felhasználói beállításokat.',
  'Here you can configure basic settings of your social network.' => 'Itt konfigurálhatod közösségi hálózatod alapbeállításait.',
  'Hide file info (name, size) for images on wall' => 'Fájl információk (név, méret) elrejtése a falon található képekhez',
  'Horizontal scrolling images on a mobile device' => 'Vízszintes görgetési képek mobileszközön',
  'Icon upload' => '',
  'If not set, height will default to 200px.' => 'Ha nincs beállítva, a magasság alapértelmezés szerint 200px.',
  'If not set, width will default to 200px.' => 'Ha nincs beállítva, a szélesség alapértelmezés szerint 200px.',
  'Image Magick convert command (optional)' => 'Image Magick konvertálás parancs (opcionális)',
  'Last visit' => 'Utolsó látogatás',
  'Logo upload' => 'Logo feltöltés',
  'Mail Transport Type' => 'Levélszállítás típusa',
  'Maximum allowed age for logs.' => 'A naplózott fájlok maximális megengedett kora.',
  'Maximum preview image height (in pixels, optional)' => 'Maximális előnézeti képmagasság (képpontban, opcionális)',
  'Maximum preview image width (in pixels, optional)' => 'Maximális előnézeti képszélesség (képpontban, opcionális)',
  'Maximum upload file size (in MB)' => 'Legnagyobb feltöltési fájlméret (MB)',
  'Name of the application' => 'Applikáció neve',
  'No Proxy Hosts' => 'Nincsenek proxy hosztok',
  'No caching' => 'Nincs gyorsítótárazás',
  'None - shows dropdown in user registration.' => 'Egyik sem - a felhasználói regisztrációkor mutatja a legördülő menüt',
  'Notification Settings' => 'Értesítési beállítások',
  'Old logs can significantly increase the size of your database while providing little information.' => 'A régi log fájlok jelentősen növelhetik az adatbázis méretét, miközben kevés információt nyújtanak.',
  'PHP APC(u) Extension missing - Type not available!' => 'Hiányzó PHP APC(u) kiterjesztés - A típus nem elérhető!',
  'PHP reported a maximum of {maxUploadSize} MB' => 'A PHP maximum {maxUploadSize} MB-t jelentett',
  'Password' => 'Jelszó',
  'Port' => 'Port',
  'Port number' => 'Portszám',
  'Redis' => 'Redis',
  'SMTP Options' => 'SMTP opciók',
  'Save' => 'Mentés',
  'Save & Flush Caches' => 'Mentés és gyorsítótárak ürítése',
  'Saved' => 'Mentve',
  'Saved and flushed cache' => 'Mentve és gyorsítótár törölve',
  'Server' => 'Szerver',
  'Server Timezone' => 'Szerver időzónája',
  'Show introduction tour for new users' => 'Oktató rész mutatása új felhasználóknak',
  'Show user profile post form on dashboard' => 'Felhasználói profil közzétételi űrlapjának megjelenítése az áttekintésben',
  'Sort by creation date' => 'Rendezés a létrehozás dátuma szerint',
  'Sort by update date' => 'Rendezés a frissítés dátuma szerint',
  'Theme' => 'Téma',
  'These settings refer to advanced topics of your social network.' => 'Ezek a beállítások közösségi hálózatod speciális témáira vonatkoznak.',
  'These settings refer to the appearance of your social network.' => 'Ezek a beállítások közösségi hálózatod megjelenésére vonatkoznak.',
  'Url Prefix' => 'URL előtagja',
  'Url Prefix without http:// or https:// (e.g. youtube.com)' => 'Url előtag http:// vagy https:// nélkül (például youtube.com)',
  'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Használja a %url% címet helykitöltőnek az URL-hez. A formátumnak a következőnek kell lennie: JSON. (pl. http://www.youtube.com/oembed?url=%url%&amp;format=json))',
  'Use X-Sendfile for File Downloads' => 'Az X-Sendfile használata fájlok letöltéséhez',
  'User' => 'Felhasználó',
  'User Settings' => 'Felhasználói beállítások',
  'Username' => 'Felhasználónév',
  'Username (e.g. john)' => 'Felhasználónév (pl. ferenc)',
  'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Hozzáadhatsz egy statisztikai HTML kódrészletet - amely minden renderelt oldalhoz hozzáadódik.',
  'never' => 'soha',
);

==> humhub-1.5.2.tar.gz: humhub-1.5.2/protected/humhub/modules/admin/messages/hu/settings.php <==
<?php
return array (
  '1 month' => '1 hónap',
  '1 week' => '1 hét',
  '1 year' => '1 év',
  '2 weeks' => '2 év',
  '3 months' => '3 hónap',
  '6 months' => '6 hónap',
  '<strong>Confirm</strong> icon deletion' => '<strong>Ikon törlés</strong> megerősítése',
  '<strong>Confirm</strong> image deletion' => 'Kép törlésének <strong>megerősítése</strong>',
  'APC(u)' => 'APC(u)',
  'Add OEmbed provider' => 'OEmbed szolgáltató hozzáadása',
  'Add new provider' => 'Új szolgáltató hozzáadása',
  'Advanced Settings' => 'Speciális beállítások',
  'Allow Self-Signed Certificates?' => 'Önaláírt tanúsítványok elfogasása?',
  'Allowed file extensions' => 'Engedélyezett fájlkiterjesztések',
  'Alphabetical' => 'ABC sorrend',
  'Appearance Settings' => 'Megjelenítési beállítások',
  'Auto format based on user language - Example: {example}' => 'Automatikus formátum a felhasználói nyelv alapján - Példa: {example}',
  'Back to overview' => 'Vissza az áttekkintéshez',
  'Base URL' => 'Alap URL',
  'Cache Backend' => 'Gyorsítótár backend',
  'Comma separated list. Leave empty to allow all.' => 'Vesszővel elválasztott lista. Hagyd üresen, ha az összeset engedélyezni akarod.',
  'Could not send test email.' => '',
  'Currently no provider active!' => 'Jelenleg egyetlen szolgáltató sem aktív!',
  'Currently there are {count} records in the database dating from {dating}.' => 'Jelenleg {count} rekord szerepel az adatbázisban, ami ekkor lett létrehozva {dating}.',
  'Dashboard' => 'Áttekintés',
  'Date input format' => 'Dátum beviteli formátuma',
  'Default Expire Time (in seconds)' => 'Alapértelmezett lejárati idő (másodpercekben)',
  'Default language' => 'Alapértelmezett nyelv',
  'Default pagination size (Entries per page)' => 'Alapértelmezett lapozásméret (oldalankénti bejegyzések)',
  'Default stream content order' => 'A stream tartalmának alapértelmezett sorrendje',
  'Delete' => 'Törlés',
  'Display Name (Format)' => 'Megjelenítési név (formátum)',
  'Dropdown space order' => 'Legördülő közösségek sorrendje',
  'E-Mail' => 'Email',
  'E-Mail sender address' => 'Email küldőjének címe',
  'E-Mail sender name' => 'E-mail küldőjének neve',
  'E.g. http://example.com/humhub' => 'Pl. http://example.com/humhub',
  'Edit OEmbed provider' => 'OEmbed szolgáltató szerkesztése',
  'Enable user friendship system' => 'Felhasználók barátkozásának engedélyezése',
  'Enabled' => 'Bekacsolva',
  'Enabled OEmbed providers' => 'Engedélyezett OEmbed szolgáltatók',
  'Encryption' => 'Enkriptálás',
  'Endpoint Url' => 'Végpont URL',
  'File' => 'Fájl',
  'Firstname Lastname (e.g. John Doe)' => 'Keresztnév/utónév (például John Doe)',
  'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Fix formátum (nap/hónap/év) - Példa: {example}',
  'Friendship' => 'Ismerősök',
  'General' => 'Általános',
  'General Settings' => 'Általános beállítások',
  'HTML tracking code' => 'HTML-követőkód',
  'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Itt konfigurálhatod közösségi hálózatod regisztrálói viselkedéssel kapcsolatos beállításait és további felhasználói beállításokat.',
  'Here you can configure basic settings of your social network.' => 'Itt konfigurálhatod közösségi hálózatod alapbeállításait.',
  'Hide file info (name, size) for images on wall' => 'Fájl információk (név, méret) elrejtése a falon található képekhez',
  'Horizontal scrolling images on a mobile device' => 'Vízszintes görgetési képek mobileszközön',
  'Icon upload' => 'Ikon feltöltés',
  'If not set, height will default to 200px.' => 'Ha nincs beállítva, a magasság alapértelmezés szerint 200px.',
  'If not set, width will default to 200px.' => 'Ha nincs beállítva, a szélesség alapértelmezés szerint 200px.',
  'Last visit' => 'Utolsó látogatás',
  'Logo upload' => 'Logo feltöltés',
  'Mail Transport Type' => 'Levélszállítás típusa',
  'Maximum allowed age for logs.' => 'A naplózott fájlok maximális megengedett kora.',
  'Maximum preview image height (in pixels, optional)' => 'Maximális előnézeti képmagasság (képpontban, opcionális)',
  'Maximum preview image width (in pixels, optional)' => 'Maximális előnézeti képszélesség (képpontban, opcionális)',
  'Maximum upload file size (in MB)' => 'Legnagyobb feltöltési fájlméret (MB)',
  'Mobile appearance' => '',
  'Name of the application' => 'Applikáció neve',
  'No Proxy Hosts' => 'Nincsenek proxy hosztok',
  'No caching' => 'Nincs gyorsítótárazás',
  'None - shows dropdown in user registration.' => 'Egyik sem - a felhasználói regisztrációkor mutatja a legördülő menüt',
  'Notification Settings' => 'Értesítési beállítások',
  'Old logs can significantly increase the size of your database while providing little information.' => 'A régi log fájlok jelentősen növelhetik az adatbázis méretét, miközben kevés információt nyújtanak.',
  'PHP APC(u) Extension missing - Type not available!' => 'Hiányzó PHP APC(u) kiterjesztés - A típus nem elérhető!',
  'PHP reported a maximum of {maxUploadSize} MB' => 'A PHP maximum {maxUploadSize} MB-t jelentett',
  'Password' => 'Jelszó',
  'Port' => 'Port',
  'Port number' => 'Portszám',
  'Prevent client caching of following scripts' => '',
  'Redis' => 'Redis',
  'SMTP Options' => 'SMTP opciók',
  'Save' => 'Mentés',
  'Save & Flush Caches' => 'Mentés és gyorsítótárak ürítése',
  'Save & Test' => 'Mentés és tesztelés',
  'Saved' => 'Mentve',
  'Saved and flushed cache' => 'Mentve és gyorsítótár törölve',
  'Server' => 'Szerver',
  'Server Timezone' => 'Szerver időzónája',
  'Show introduction tour for new users' => 'Oktató rész mutatása új felhasználóknak',
  'Show user profile post form on dashboard' => 'Felhasználói profil közzétételi űrlapjának megjelenítése az áttekintésben',
  'Sort by creation date' => 'Rendezés a létrehozás dátuma szerint',
  'Sort by update date' => 'Rendezés a frissítés dátuma szerint',
  'Test message' => '',
  'Theme' => 'Téma',
  'These settings refer to advanced topics of your social network.' => 'Ezek a beállítások közösségi hálózatod speciális témáira vonatkoznak.',
  'These settings refer to the appearance of your social network.' => 'Ezek a beállítások közösségi hálózatod megjelenésére vonatkoznak.',
  'Url Prefix' => 'URL előtagja',
  'Url Prefix without http:// or https:// (e.g. youtube.com)' => 'Url előtag http:// vagy https:// nélkül (például youtube.com)',
  'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Használja a %url% címet helykitöltőnek az URL-hez. A formátumnak a következőnek kell lennie: JSON. (pl. http://www.youtube.com/oembed?url=%url%&amp;format=json))',
  'Use X-Sendfile for File Downloads' => 'Az X-Sendfile használata fájlok letöltéséhez',
  'Use the default swipe to show sidebar on a mobile device' => '',
  'User' => 'Felhasználó',
  'User Settings' => 'Felhasználói beállítások',
  'Username' => 'Felhasználónév',
  'Username (e.g. john)' => 'Felhasználónév (pl. ferenc)',
  'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Hozzáadhatsz egy statisztikai HTML kódrészletet - amely minden renderelt oldalhoz hozzáadódik.',
  'You\'re using no icon at the moment. Upload your logo now.' => '',
  'You\'re using no logo at the moment. Upload your logo now.' => 'Jelenleg nem használsz logót. Töltsd fel logódat most.',
  'never' => 'soha',
);
